# ModelZoo in a nutshell

{sub-ref}`wordcount-words` words | {sub-ref}`wordcount-minutes` min read

Models are the cornerstone of machine learning. New models and architectures are constantly being developed but using
multiple tools from different sources quickly becomes tedious, inconvenient, and prone to incompatibilities.

The ``modelzoo`` submodule aims to address these issues. It is a collection of many different types
of models. Whether you are trying to work with classical models (such as a random forest regressor) or deep learning models
(such as GNNs or transformers), ``modelzoo`` provides a standard and modular interface for using these models and also
allows you to add your own!
